@@ -6,7 +6,7 @@ import time
 from itertools import cycle
 from sys import platform
 from time import sleep
-from typing import Any, Dict, List, Optional, Set, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 
 import dateutil.parser
 
@@ -473,6 +473,7 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
         log_backend: LogsBackend,
         container_overrides: Optional[Dict[str, Any]],
         depends_on: Optional[List[Dict[str, str]]],
+        parameters: Optional[Dict[str, str]],
         all_jobs: Dict[str, "Job"],
         timeout: Optional[Dict[str, int]],
         array_properties: Dict[str, Any],
@@ -498,6 +499,7 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
         self.job_stopped = False
         self.job_stopped_reason: Optional[str] = None
         self.depends_on = depends_on
+        self.parameters = {**self.job_definition.parameters, **(parameters or {})}
         self.timeout = timeout
         self.all_jobs = all_jobs
         self.array_properties: Dict[str, Any] = array_properties
@@ -546,6 +548,7 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
         result = self.describe_short()
         result["jobQueue"] = self.job_queue.arn
         result["dependsOn"] = self.depends_on or []
+        result["parameters"] = {**self.job_definition.parameters, **self.parameters}
         if self.job_definition.type == "container":
             result["container"] = self._container_details()
         elif self.job_definition.type == "multinode":
@@ -628,6 +631,25 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
             return self.job_definition.timeout["attemptDurationSeconds"]
         return None
 
+    def _add_parameters_to_command(self, command: Union[str, List[str]]) -> List[str]:
+        if isinstance(command, str):
+            command = [command]
+
+        if not self.parameters:
+            return command
+
+        return [
+            next(
+                (
+                    command_part.replace(f"Ref::{param}", value)
+                    for param, value in self.parameters.items()
+                    if f"Ref::{param}" in command_part
+                ),
+                command_part,
+            )
+            for command_part in command
+        ]
+
     def run(self) -> None:
         """
         Run the container.
@@ -676,9 +698,11 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
                         "privileged": self.job_definition.container_properties.get(
                             "privileged", False
                         ),
-                        "command": self._get_container_property(
-                            "command",
-                            '/bin/sh -c "for a in `seq 1 10`; do echo Hello World; sleep 1; done"',
+                        "command": self._add_parameters_to_command(
+                            self._get_container_property(
+                                "command",
+                                '/bin/sh -c "for a in `seq 1 10`; do echo Hello World; sleep 1; done"',
+                            )
                         ),
                         "environment": {
                             e["name"]: e["value"]
@@ -723,9 +747,11 @@ class Job(threading.Thread, BaseModel, DockerModel, ManagedState):
                         {
                             "image": spec.get("image", "alpine:latest"),
                             "privileged": spec.get("privileged", False),
-                            "command": spec.get(
-                                "command",
-                                '/bin/sh -c "for a in `seq 1 10`; do echo Hello World; sleep 1; done"',
+                            "command": self._add_parameters_to_command(
+                                spec.get(
+                                    "command",
+                                    '/bin/sh -c "for a in `seq 1 10`; do echo Hello World; sleep 1; done"',
+                                )
                             ),
                             "environment": {
                                 e["name"]: e["value"]
@@ -1729,6 +1755,7 @@ class BatchBackend(BaseBackend):
         depends_on: Optional[List[Dict[str, str]]] = None,
         container_overrides: Optional[Dict[str, Any]] = None,
         timeout: Optional[Dict[str, int]] = None,
+        parameters: Optional[Dict[str, str]] = None,
     ) -> Tuple[str, str, str]:
         """
         Parameters RetryStrategy and Parameters are not yet implemented.
@@ -1755,6 +1782,7 @@ class BatchBackend(BaseBackend):
             all_jobs=self._jobs,
             timeout=timeout,
             array_properties=array_properties or {},
+            parameters=parameters,
         )
         self._jobs[job.job_id] = job
 
@@ -1772,6 +1800,7 @@ class BatchBackend(BaseBackend):
                     all_jobs=self._jobs,
                     timeout=timeout,
                     array_properties={"statusSummary": {}, "index": array_index},
+                    parameters=parameters,
                     provided_job_id=provided_job_id,
                 )
                 child_jobs.append(child_job)
@@ -1806,25 +1835,32 @@ class BatchBackend(BaseBackend):
 
     def list_jobs(
         self,
-        job_queue_name: str,
+        job_queue_name: Optional[str],
+        array_job_id: Optional[str],
         job_status: Optional[str] = None,
         filters: Optional[List[Dict[str, Any]]] = None,
     ) -> List[Job]:
         """
         Pagination is not yet implemented
         """
+        jobs_to_check = []
         jobs = []
 
-        job_queue = self.get_job_queue(job_queue_name)
-        if job_queue is None:
-            raise ClientException(f"Job queue {job_queue_name} does not exist")
+        if job_queue_name:
+            if job_queue := self.get_job_queue(job_queue_name):
+                jobs_to_check.extend(job_queue.jobs)
+            else:
+                raise ClientException(f"Job queue {job_queue_name} does not exist")
+        if array_job_id:
+            if array_job := self.get_job_by_id(array_job_id):
+                jobs_to_check.extend(array_job._child_jobs or [])
 
         if job_status is not None and job_status not in JobStatus.job_statuses():
             raise ClientException(
                 "Job status is not one of SUBMITTED | PENDING | RUNNABLE | STARTING | RUNNING | SUCCEEDED | FAILED"
             )
 
-        for job in job_queue.jobs:
+        for job in jobs_to_check:
             if job_status is not None and job.status != job_status:
                 continue
 
