@@ -659,7 +659,16 @@ class CloudWatchBackend(BaseBackend):
         results = []
         results_to_return = []
         metric_stat_queries = [q for q in queries if "MetricStat" in q]
-        expression_queries = [q for q in queries if "Expression" in q]
+        metric_math_expression_queries = [
+            q
+            for q in queries
+            if "Expression" in q and not q["Expression"].startswith("SELECT")
+        ]
+        metric_insights_expression_queries = [
+            q
+            for q in queries
+            if "Expression" in q and q["Expression"].startswith("SELECT")
+        ]
         for query in metric_stat_queries:
             period_start_time = start_time
             metric_stat = query["MetricStat"]
@@ -730,8 +739,9 @@ class CloudWatchBackend(BaseBackend):
                         "timestamps": timestamps,
                     }
                 )
-        for query in expression_queries:
-            label = query.get("Label") or f"{query_name} {stat}"
+        # Metric Math expression Queries run on top of the results of other queries
+        for query in metric_math_expression_queries:
+            label = query.get("Label") or query["Id"]
             result_vals, timestamps = parse_expression(query["Expression"], results)
             results_to_return.append(
                 {
@@ -741,6 +751,44 @@ class CloudWatchBackend(BaseBackend):
                     "timestamps": timestamps,
                 }
             )
+        # Metric Insights Expression Queries act on all results, and are essentially SQL queries
+        for query in metric_insights_expression_queries:
+            period_start_time = start_time
+            delta = timedelta(seconds=int(query["Period"]))
+            result_vals: List[SupportsFloat] = []  # type: ignore[no-redef]
+            timestamps: List[str] = []  # type: ignore[no-redef]
+            while period_start_time <= end_time:
+                period_end_time = period_start_time + delta
+                period_md = [
+                    period_md
+                    for period_md in period_data
+                    if period_start_time <= period_md.timestamp < period_end_time
+                ]
+
+                # https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch-metrics-insights-querylanguage.html
+                # We should filter even further, but Moto currently does not support Metrics Insights Queries
+                # Let's just add all metric data found within this period
+
+                if len(period_md) > 0:
+                    stats = Statistics(["Sum"], period_start_time)
+                    stats.metric_data = period_md
+                    result_vals.append(stats.get_statistics_for_type("Sum"))  # type: ignore[arg-type]
+
+                    timestamps.append(stats.timestamp)
+                period_start_time += delta
+            if scan_by == "TimestampDescending" and len(timestamps) > 0:
+                timestamps.reverse()
+                result_vals.reverse()
+
+            results_to_return.append(
+                {
+                    "id": query["Id"],
+                    "label": (query.get("Label") or query["Id"]),
+                    "vals": result_vals,
+                    "timestamps": timestamps,
+                }
+            )
+
         return results_to_return
 
     def get_metric_statistics(
