@@ -3,7 +3,7 @@ import re
 from collections import defaultdict
 from typing import Any, Dict, Tuple, Union
 
-from moto.core.responses import BaseResponse
+from moto.core.responses import TYPE_RESPONSE, BaseResponse
 from moto.core.utils import camelcase_to_underscores
 
 from .exceptions import InvalidParameterValue, SNSNotFoundError
@@ -346,6 +346,7 @@ class SNSResponse(BaseResponse):
         subject = self._get_param("Subject")
         message_group_id = self._get_param("MessageGroupId")
         message_deduplication_id = self._get_param("MessageDeduplicationId")
+        message_structure = self._get_param("MessageStructure")
 
         message_attributes = self._parse_message_attributes()
 
@@ -375,6 +376,7 @@ class SNSResponse(BaseResponse):
                 message_attributes=message_attributes,
                 group_id=message_group_id,
                 deduplication_id=message_deduplication_id,
+                message_structure=message_structure,
             )
         except ValueError as err:
             error_response = self._error("InvalidParameter", str(err))
@@ -802,6 +804,14 @@ class SNSResponse(BaseResponse):
 
         return self.response_template(UNTAG_RESOURCE_TEMPLATE).render()
 
+    @staticmethod
+    def serve_pem(request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
+        sns = SNSResponse()
+        sns.setup_class(request, full_url, headers)
+        key_name = full_url.split("/")[-1]
+        key = sns.backend._message_public_keys[key_name]
+        return 200, {}, key
+
 
 CREATE_TOPIC_TEMPLATE = """<CreateTopicResponse xmlns="http://sns.amazonaws.com/doc/2010-03-31/">
      <CreateTopicResult>
