@@ -2,7 +2,7 @@ from moto.stepfunctions.parser.asl.component.intrinsic.argument.function_argumen
     FunctionArgument,
 )
 from moto.stepfunctions.parser.asl.eval.environment import Environment
-from moto.stepfunctions.parser.asl.utils.json_path import JSONPathUtils
+from moto.stepfunctions.parser.asl.utils.json_path import extract_json
 
 
 class FunctionArgumentContextPath(FunctionArgument):
@@ -13,7 +13,7 @@ class FunctionArgumentContextPath(FunctionArgument):
         self._json_path: str = json_path
 
     def _eval_body(self, env: Environment) -> None:
-        self._value = JSONPathUtils.extract_json(
-            self._json_path, env.context_object_manager.context_object
+        self._value = extract_json(
+            self._json_path, env.states.context_object.context_object_data
         )
         super()._eval_body(env=env)
