@@ -326,6 +326,63 @@ def test_query_gsi_pagination_with_string_gsi_range(table_name=None):
     assert subjects == set(range(10))
 
 
+@mock_aws
+def test_query_gsi_pagination_with_opposite_pk_order():
+    dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
+
+    # Create the DynamoDB table.
+    dynamodb.create_table(
+        TableName="users",
+        KeySchema=[
+            {"AttributeName": "pk", "KeyType": "HASH"},
+        ],
+        AttributeDefinitions=[
+            {"AttributeName": "pk", "AttributeType": "S"},
+            {"AttributeName": "gsi_hash", "AttributeType": "S"},
+            {"AttributeName": "gsi_sort", "AttributeType": "S"},
+        ],
+        ProvisionedThroughput={"ReadCapacityUnits": 5, "WriteCapacityUnits": 5},
+        GlobalSecondaryIndexes=[
+            {
+                "IndexName": "gsi",
+                "KeySchema": [
+                    {"AttributeName": "gsi_hash", "KeyType": "HASH"},
+                    {"AttributeName": "gsi_sort", "KeyType": "RANGE"},
+                ],
+                "Projection": {"ProjectionType": "ALL"},
+            }
+        ],
+    )
+    table = dynamodb.Table("users")
+
+    table.put_item(Item={"pk": "b", "gsi_hash": "a", "gsi_sort": "a"})
+    table.put_item(Item={"pk": "a", "gsi_hash": "a", "gsi_sort": "b"})
+
+    page1 = table.query(
+        KeyConditionExpression=Key("gsi_hash").eq("a"),
+        IndexName="gsi",
+        Limit=1,
+    )
+    assert page1["Count"] == 1
+    assert page1["ScannedCount"] == 1
+    assert len(page1["Items"]) == 1
+
+    page2 = table.query(
+        KeyConditionExpression=Key("gsi_hash").eq("a"),
+        IndexName="gsi",
+        Limit=1,
+        ExclusiveStartKey=page1["LastEvaluatedKey"],
+    )
+    assert page2["Count"] == 1
+    assert page2["ScannedCount"] == 1
+    assert len(page2["Items"]) == 1
+    assert "LastEvaluatedKey" not in page2
+
+    results = page1["Items"] + page2["Items"]
+    subjects = [(r["pk"]) for r in results]
+    assert subjects == ["b", "a"]
+
+
 @pytest.mark.aws_verified
 @dynamodb_aws_verified(add_range=True, add_gsi_range=True)
 def test_query_gsi_pagination_with_string_gsi_range_and_empty_gsi_pk(table_name=None):
@@ -810,3 +867,28 @@ def test_query_gsi_pagination_with_string_gsi_range_no_sk(table_name=None):
     results = page1["Items"] + page2["Items"]
     subjects = set([int(r["pk"]) for r in results])
     assert subjects == set(range(10))
+
+
+@pytest.mark.aws_verified
+@dynamodb_aws_verified(add_range=True)
+def test_key_condition_expression_with_brackets(table_name=None):
+    dynamodb = boto3.resource("dynamodb", region_name="us-east-1")
+    table = dynamodb.Table(table_name)
+
+    table.put_item(Item={"pk": "TEST", "sk": "aa"})
+    table.put_item(Item={"pk": "TEST", "sk": "ab"})
+    table.put_item(Item={"pk": "TEST", "sk": "ac"})
+
+    results = table.query(
+        KeyConditionExpression="(#0 = :0) AND (begins_with(#1, :1))",
+        ExpressionAttributeNames={"#0": "pk", "#1": "sk"},
+        ExpressionAttributeValues={":0": "TEST", ":1": "a"},
+    )
+    assert results["Count"] == 3
+
+    results = table.query(
+        KeyConditionExpression="(#0 = :0) AND (#1 BETWEEN :1 AND :2)",
+        ExpressionAttributeNames={"#0": "pk", "#1": "sk"},
+        ExpressionAttributeValues={":0": "TEST", ":1": "ab", ":2": "ab"},
+    )
+    assert results["Items"] == [{"pk": "TEST", "sk": "ab"}]
