@@ -606,8 +606,14 @@ def test_routes_replace():
         ]
     )["RouteTables"][0]["RouteTableId"]
     main_route_table = ec2.RouteTable(main_route_table_id)
+
+    # Various route sources
     ROUTE_CIDR = "10.0.0.4/24"
 
+    prefix_list = client.create_managed_prefix_list(
+        PrefixListName="examplelist", MaxEntries=2, AddressFamily="?"
+    )["PrefixList"]
+
     # Various route targets
     igw = ec2.create_internet_gateway()
 
@@ -626,7 +632,8 @@ def test_routes_replace():
         routes = [
             route
             for route in route_table["Routes"]
-            if route["DestinationCidrBlock"] != vpc.cidr_block
+            if "DestinationCidrBlock" not in route
+            or route["DestinationCidrBlock"] != vpc.cidr_block
         ]
         assert len(routes) == 1
         return routes[0]
@@ -692,6 +699,30 @@ def test_routes_replace():
     # equivalent, but for some reason AWS returns InvalidParameterValue instead.
     assert ex.value.response["Error"]["Code"] == "InvalidParameterValue"
 
+    # Remove route
+    client.delete_route(
+        RouteTableId=main_route_table.id, DestinationCidrBlock=ROUTE_CIDR
+    )
+
+    # Create prefix list source route
+    main_route_table.create_route(
+        DestinationPrefixListId=prefix_list["PrefixListId"], GatewayId=igw.id
+    )
+
+    # Replace...
+    client.replace_route(
+        RouteTableId=main_route_table.id,
+        DestinationPrefixListId=prefix_list["PrefixListId"],
+        InstanceId=instance.id,
+    )
+
+    target_route = get_target_route()
+    assert "GatewayId" not in target_route
+    assert target_route["InstanceId"] == instance.id
+    assert "NetworkInterfaceId" not in target_route
+    assert target_route["State"] == "active"
+    assert target_route["DestinationPrefixListId"] == prefix_list["PrefixListId"]
+
 
 @mock_aws
 def test_routes_already_exist():
