@@ -6,7 +6,6 @@ from uuid import uuid4
 import boto3
 import pytest
 from botocore.client import ClientError
-from botocore.exceptions import ParamValidationError
 
 from moto import mock_aws
 
@@ -36,15 +35,6 @@ def test_delete_job():
     assert exc.value.response["Error"]["Code"] == "EntityNotFoundException"
 
 
-@mock_aws
-def test_create_job_default_argument_not_provided():
-    client = create_glue_client()
-    with pytest.raises(ParamValidationError) as exc:
-        client.create_job(Role="test_role", Command=dict(Name="test_command"))
-
-    assert exc.value.kwargs["report"] == 'Missing required parameter in input: "Name"'
-
-
 @mock_aws
 def test_list_jobs():
     client = create_glue_client()
@@ -867,3 +857,155 @@ def test_stop_session():
 
     resp = client.get_session(Id=session_id)
     assert resp["Session"]["Status"] == "STOPPING"
+
+
+@mock_aws
+def test_get_dev_endpoints():
+    client = create_glue_client()
+
+    response = client.get_dev_endpoints()
+    assert response["DevEndpoints"] == []
+    assert "NextToken" not in response
+
+    client.create_dev_endpoint(
+        EndpointName="dev-endpoint-1",
+        RoleArn="arn:aws:iam::123456789012:role/GlueDevEndpoint",
+    )
+    client.create_dev_endpoint(
+        EndpointName="dev-endpoint-2",
+        RoleArn="arn:aws:iam::123456789012:role/GlueDevEndpoint",
+    )
+
+    response = client.get_dev_endpoints()
+    assert len(response["DevEndpoints"]) == 2
+    assert {ep["EndpointName"] for ep in response["DevEndpoints"]} == {
+        "dev-endpoint-1",
+        "dev-endpoint-2",
+    }
+    assert "NextToken" not in response
+
+    response = client.get_dev_endpoints(MaxResults=1)
+    assert len(response["DevEndpoints"]) == 1
+    assert "NextToken" in response
+
+    next_token = response["NextToken"]
+    response = client.get_dev_endpoints(NextToken=next_token)
+    assert len(response["DevEndpoints"]) == 1
+    assert "NextToken" not in response
+
+
+@mock_aws
+def test_create_dev_endpoint():
+    client = create_glue_client()
+
+    response = client.create_dev_endpoint(
+        EndpointName="test-endpoint",
+        RoleArn="arn:aws:iam::123456789012:role/GlueDevEndpoint",
+    )
+
+    assert response["EndpointName"] == "test-endpoint"
+    assert response["Status"] == "READY"
+    assert response["RoleArn"] == "arn:aws:iam::123456789012:role/GlueDevEndpoint"
+
+
+@mock_aws
+def test_get_dev_endpoint():
+    client = create_glue_client()
+
+    client.create_dev_endpoint(
+        EndpointName="test-endpoint",
+        RoleArn="arn:aws:iam::123456789012:role/GlueDevEndpoint",
+    )
+
+    response = client.get_dev_endpoint(EndpointName="test-endpoint")
+    assert response["DevEndpoint"]["EndpointName"] == "test-endpoint"
+    assert response["DevEndpoint"]["Status"] == "READY"
+    assert "PublicAddress" in response["DevEndpoint"]
+
+    with pytest.raises(client.exceptions.EntityNotFoundException):
+        client.get_dev_endpoint(EndpointName="nonexistent")
+
+    client.create_dev_endpoint(
+        EndpointName="test-endpoint-private",
+        RoleArn="arn:aws:iam::123456789012:role/GlueDevEndpoint",
+        SubnetId="subnet-1234567890abcdef0",
+    )
+
+    response = client.get_dev_endpoint(EndpointName="test-endpoint-private")
+    assert response["DevEndpoint"]["EndpointName"] == "test-endpoint-private"
+    assert "PublicAddress" not in response["DevEndpoint"]
+
+
+@mock_aws
+def test_create_connection():
+    client = boto3.client("glue", region_name="us-east-2")
+    subnet_id = "subnet-1234567890abcdef0"
+    connection_input = {
+        "Name": "test-connection",
+        "Description": "Test Connection",
+        "ConnectionType": "JDBC",
+        "ConnectionProperties": {"key": "value"},
+        "PhysicalConnectionRequirements": {
+            "SubnetId": subnet_id,
+            "SecurityGroupIdList": [],
+            "AvailabilityZone": "us-east-1a",
+        },
+    }
+    resp = client.create_connection(ConnectionInput=connection_input)
+    assert resp["CreateConnectionStatus"] == "READY"
+
+    # Test duplicate name
+    with pytest.raises(client.exceptions.AlreadyExistsException):
+        client.create_connection(ConnectionInput=connection_input)
+
+
+@mock_aws
+def test_get_connection():
+    client = boto3.client("glue", region_name="us-east-2")
+    subnet_id = "subnet-1234567890abcdef0"
+    connection_input = {
+        "Name": "test-connection",
+        "Description": "Test Connection",
+        "ConnectionType": "JDBC",
+        "ConnectionProperties": {"key": "value"},
+        "PhysicalConnectionRequirements": {
+            "SubnetId": subnet_id,
+            "SecurityGroupIdList": [],
+            "AvailabilityZone": "us-east-1a",
+        },
+    }
+    client.create_connection(ConnectionInput=connection_input)
+    connection = client.get_connection(Name="test-connection")["Connection"]
+    assert connection["Name"] == "test-connection"
+    assert connection["Status"] == "READY"
+    assert "PhysicalConnectionRequirements" in connection_input
+    assert connection["PhysicalConnectionRequirements"]["SubnetId"] == subnet_id
+
+    # Test not found
+    with pytest.raises(client.exceptions.EntityNotFoundException):
+        client.get_connection(Name="nonexistent")
+
+
+@mock_aws
+def test_get_connections():
+    client = boto3.client("glue", region_name="ap-southeast-1")
+    for i in range(3):
+        subnet_id = f"subnet-1234567890abcdef{i}"
+        connection_input = {
+            "Name": f"test-connection-{i}",
+            "Description": "Test Connection",
+            "ConnectionType": "JDBC",
+            "ConnectionProperties": {"key": "value"},
+            "PhysicalConnectionRequirements": {
+                "SubnetId": subnet_id,
+                "SecurityGroupIdList": [],
+                "AvailabilityZone": "us-east-1a",
+            },
+        }
+        client.create_connection(ConnectionInput=connection_input)
+
+    connections = client.get_connections()["ConnectionList"]
+    assert len(connections) == 3
+    assert connections[0]["Name"] == "test-connection-0"
+    assert connections[1]["Name"] == "test-connection-1"
+    assert connections[2]["Name"] == "test-connection-2"
