@@ -1,4 +1,3 @@
-from time import sleep
 from unittest import SkipTest, mock
 from uuid import uuid4
 
@@ -7,6 +6,7 @@ import pytest
 
 from moto import mock_aws, settings
 from moto.s3.responses import DEFAULT_REGION_NAME
+from tests.test_s3.test_s3 import enable_versioning
 
 from . import s3_aws_verified
 
@@ -631,17 +631,6 @@ def test_list_object_versions__sort_order(bucket_name=None):
     assert version_list["DeleteMarkers"][0]["VersionId"] == b_del
 
 
-def enable_versioning(bucket_name, s3_client):
-    s3_client.put_bucket_versioning(
-        Bucket=bucket_name, VersioningConfiguration={"Status": "Enabled"}
-    )
-    # Versioning is not active immediately, so wait until we have confirmation the change has gone through
-    resp = {}
-    while resp.get("Status") != "Enabled":
-        sleep(0.1)
-        resp = s3_client.get_bucket_versioning(Bucket=bucket_name)
-
-
 @mock_aws
 @mock.patch.dict("os.environ", {"MOTO_S3_DEFAULT_MAX_KEYS": "5"})
 def test_list_object_versions_with_custom_limit():
